@@ -1,65 +1,13 @@
 """
 Tagulous tag models
 """
-from __future__ import unicode_literals
-
-import django
-from django.db import IntegrityError, connection, models, router, transaction
+from django.db import IntegrityError, models, router, transaction
 from django.db.models import F, Max
-from django.utils import six
-from django.utils.encoding import python_2_unicode_compatible
+from django.db.models.functions import Floor
+from django.utils.text import slugify
 
-import tagulous
-from tagulous import constants, settings, utils
-from tagulous.models.options import TagOptions
-
-
-try:
-    from django.utils.text import slugify
-except ImportError:
-    # Django 1.4 or earlier
-    from django.template.defaultfilters import slugify
-
-
-# Django 1.4 and 1.5 don't support transaction.atomic, but don't need it for
-# what we're doing here; fake it for the ``with`` statement.
-if hasattr(transaction, "atomic"):
-    transaction_atomic = transaction.atomic
-else:
-
-    class transaction_atomic(object):
-        def __enter__(self):
-            pass
-
-        def __exit__(self, type, value, traceback):
-            pass
-
-
-# Fix for with_metaclass in Django 1.5
-# 1.4.2 and 1.6 use the same code, but it's different in 1.5 and we lose _meta
-# This is the fn from 1.6, adapted to work with unicode_literals
-if django.VERSION < (1, 6):
-    tmp_cls_name = "temporary_class"
-    if six.PY2:
-        tmp_cls_name = bytes(tmp_cls_name)
-
-    def with_metaclass(meta, *bases):
-        class metaclass(meta):
-            def __new__(cls, name, this_bases, d):
-                return meta(name, bases, d)
-
-        return type.__new__(metaclass, tmp_cls_name, (), {})
-
-
-else:
-    with_metaclass = six.with_metaclass
-
-
-# Django 2.2 adds Floor model function
-try:
-    from django.db.models.functions import Floor
-except ImportError:
-    Floor = None
+from .. import constants, settings, utils
+from .options import TagOptions
 
 
 # ##############################################################################
@@ -67,7 +15,6 @@ except ImportError:
 # ##############################################################################
 
 
-@python_2_unicode_compatible
 class TagModelQuerySet(models.query.QuerySet):
     def initial(self):
         """
@@ -98,51 +45,17 @@ class TagModelQuerySet(models.query.QuerySet):
         # Ignoring PEP 8 intentionally regarding conflict of min/max keywords -
         # concerns are outweighed by clarity of function argument names.
 
-        # Django 2.2 supports Floor
-        if Floor is not None:
-            # Weight is the count scaled to the min/max bounds
-            # weight = ( (count * (max - min)) / max_count ) + min
-            scale = int(max) - int(min)
-
-            max_count = self.model.objects.aggregate(Max("count"))["count__max"] or 0
-
-            # Django 2.2
-            qs = self.annotate(
-                weight=(Floor(F("count") * scale) / max_count) + int(min)
-            )
-
-        else:
-            # Build SQL
-            template = (
-                "%(floor)s((count*%(upper)d)/"
-                "(SELECT NULLIF(MAX(count), 0) FROM %(table)s)"
-                ")+%(lower)d"
-            )
-            data = {
-                "floor": "FLOOR",
-                "upper": int(max - min),
-                "lower": int(min),
-                "table": '"%s"' % self.model._meta.db_table,
-            }
-
-            # Sqlite doesn't support FLOOR, but that's ok because it does it anyway
-            if connection.vendor == "sqlite":
-                data["floor"] = ""
-
-            # MySQL doesn't support double quoted tablenames, use backticks instead
-            if connection.vendor == "mysql":
-                data["table"] = "`%s`" % self.model._meta.db_table
-
-            # Perform query and add it as `weight`
-            qs = self.extra(select={"weight": template % data})
-
+        # Weight is the count scaled to the min/max bounds
+        # weight = ( (count * (max - min)) / max_count ) + min
+        scale = int(max) - int(min)
+        max_count = self.model.objects.aggregate(Max("count"))["count__max"] or 0
+        qs = self.annotate(weight=(Floor(F("count") * scale) / max_count) + int(min))
         return qs
 
     def __str__(self):
         return utils.render_tags(self)
 
 
-@python_2_unicode_compatible
 class TagModelManager(models.Manager):
     def get_queryset(self):
         return TagModelQuerySet(self.model, using=self._db)
@@ -150,7 +63,7 @@ class TagModelManager(models.Manager):
     get_query_set = get_queryset
 
     def __str__(self):
-        return six.text_type(self.get_queryset())
+        return str(self.get_queryset())
 
     def initial(self):
         return self.get_queryset().initial()
@@ -228,12 +141,11 @@ class TagModelBase(models.base.ModelBase):
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 
 
-@python_2_unicode_compatible
-class BaseTagModel(with_metaclass(TagModelBase, models.Model)):
+class BaseTagModel(models.Model, metaclass=TagModelBase):
     """
     Empty abstract base class for tag models
 
-    This is used when dynamically building models, eg by South in migrations
+    This is used when dynamically building models, eg in migrations
     """
 
     objects = TagModelManager()
@@ -242,14 +154,14 @@ class BaseTagModel(with_metaclass(TagModelBase, models.Model)):
         abstract = True
 
     def __str__(self):
-        return six.text_type(self.name)
+        return str(self.name)
 
     def __eq__(self, obj):
         """
         If comparing to a string, is equal if string value matches
         Otherwise compares normally
         """
-        if isinstance(obj, six.string_types):
+        if isinstance(obj, str):
             return self.name == obj
         return super(BaseTagModel, self).__eq__(obj)
 
@@ -274,32 +186,25 @@ class BaseTagModel(with_metaclass(TagModelBase, models.Model)):
         If include_standard=False (default), only SingleTagFields and
         TagFields will be returned. If True, it will also include ForeignKeys
         and ManyToManyFields.
-
-        In Django 1.7 it will be a list RelatedObjects.
         """
+        # Avoid circular import
+        from .fields import SingleTagField, TagField
+
         meta = cls._meta
-        if hasattr(meta, "get_fields"):
-            # Django 1.8 uses new meta API
-            related_fields = [
-                f
-                for f in meta.get_fields()
-                if (f.many_to_many or f.one_to_many or f.one_to_one) and f.auto_created
-            ]
-        else:
-            related_fields = meta.get_all_related_objects()
-            related_fields += meta.get_all_related_many_to_many_objects()
+
+        related_fields = [
+            f
+            for f in meta.get_fields()
+            if (f.many_to_many or f.one_to_many or f.one_to_one) and f.auto_created
+        ]
+
         if include_standard:
             return related_fields
+
         return [
             f
             for f in related_fields
-            if isinstance(
-                f.field,
-                (
-                    tagulous.models.fields.SingleTagField,
-                    tagulous.models.fields.TagField,
-                ),
-            )
+            if isinstance(f.field, (SingleTagField, TagField,),)
         ]
 
     def get_related_objects(self, flat=False, distinct=False, include_standard=False):
@@ -329,10 +234,7 @@ class BaseTagModel(with_metaclass(TagModelBase, models.Model)):
         """
         data = []
         for related in self.get_related_fields(include_standard=include_standard):
-            if django.VERSION < (1, 8):
-                related_model = related.model
-            else:
-                related_model = related.related_model
+            related_model = related.related_model
 
             objs = related_model._base_manager.using(
                 router.db_for_write(self.tag_model)
@@ -385,11 +287,7 @@ class BaseTagModel(with_metaclass(TagModelBase, models.Model)):
         # Reload count
         # Use DB for write because we just updated the value
         using = router.db_for_write(self.tag_model, instance=self)
-        if hasattr(self, "refresh_from_db"):
-            self.refresh_from_db(using=using)
-        else:
-            # Django 1.7 or earlier
-            self.count = self.__class__.objects.using(using).get(pk=self.pk).count
+        self.refresh_from_db(using=using)
 
         self.try_delete()
 
@@ -429,7 +327,7 @@ class BaseTagModel(with_metaclass(TagModelBase, models.Model)):
         excluding self
         """
         # Ensure tags is a list of tag instances
-        if isinstance(tags, six.string_types):
+        if isinstance(tags, str):
             tags = utils.parse_tags(
                 tags, space_delimiter=self.tag_options.space_delimiter
             )
@@ -443,29 +341,28 @@ class BaseTagModel(with_metaclass(TagModelBase, models.Model)):
         """
         Merge the specified tags into this tag
         """
+        # Avoid circular import
+        from .fields import SingleTagField, TagField
+
         related_fields = self.tag_model.get_related_fields()
         tags = self._prep_merge_tags(tags)
 
         for related in related_fields:
             # Get the instances of the related models which refer to the tag
             # instances being merged
-            if django.VERSION < (1, 8):
-                related_model = related.model
-            else:
-                related_model = related.related_model
+            related_model = related.related_model
 
             objs = related_model._base_manager.using(
                 router.db_for_write(self.tag_model, instance=self)
             ).filter(**{"%s__in" % related.field.name: tags})
 
             # Switch the tags
-            # Referring via tagulous to avoid circular import
-            if isinstance(related.field, tagulous.models.SingleTagField):
+            if isinstance(related.field, SingleTagField):
                 for obj in objs:
                     setattr(obj, related.field.name, self)
                     obj.save()
 
-            elif isinstance(related.field, tagulous.models.TagField):
+            elif isinstance(related.field, TagField):
                 for obj in objs:
                     getattr(obj, related.field.name).remove(*tags)
                     getattr(obj, related.field.name).add(self)
@@ -513,7 +410,7 @@ class BaseTagModel(with_metaclass(TagModelBase, models.Model)):
         if settings.SLUG_ALLOW_UNICODE:
             slug_base = slugify(label, allow_unicode=True)
         else:
-            slug_base = slugify(six.text_type(utils.unicode_to_ascii(label)))
+            slug_base = slugify(str(utils.unicode_to_ascii(label)))
         self.slug = slug_base[:slug_max_length]
         self._update_extra()
 
@@ -526,7 +423,7 @@ class BaseTagModel(with_metaclass(TagModelBase, models.Model)):
             # If transaction supports atomic, we need to wrap the save call -
             # otherwise if save throws an exception it'll cause any current
             # queries to roll back
-            with transaction_atomic():
+            with transaction.atomic():
                 return super(BaseTagModel, self).save(*args, **kwargs)
         except IntegrityError:
             pass
@@ -686,11 +583,11 @@ class TagTreeModelBase(TagModelBase):
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 
 
-class BaseTagTreeModel(with_metaclass(TagTreeModelBase, BaseTagModel)):
+class BaseTagTreeModel(BaseTagModel, metaclass=TagTreeModelBase):
     """
     Empty abstract base class for tag models with tree
 
-    This is used when dynamically building models, eg by South in migrations
+    This is used when dynamically building models, eg in migrations
     """
 
     objects = TagTreeModelManager()
