@@ -8,26 +8,14 @@ Modules tested:
     tagulous.models.fields.BaseTagField
     tagulous.models.fields.TagField
 """
-from __future__ import absolute_import, unicode_literals
-
-import unittest
-
-import django
 from django.db import models
 from django.test import TestCase, TransactionTestCase
-from django.utils import six
 
 from tagulous import models as tag_models
 from tests.lib import TagTestManager, skip_if_mysql
 from tests.tagulous_tests_app import models as test_models
 
 
-try:
-    from django.core.checks import Warning as ChecksWarning
-except ImportError:
-    ChecksWarning = None
-
-
 class ModelTagFieldTest(TagTestManager, TestCase):
     """
     Test model TagField
@@ -46,14 +34,9 @@ class ModelTagFieldTest(TagTestManager, TestCase):
 
     def test_tag_table(self):
         "Check the tag table exists"
-        if django.VERSION < (1, 9):
-            self.assertTrue(
-                issubclass(self.tag_field.field.remote_field.to, tag_models.TagModel)
-            )
-        else:
-            self.assertTrue(
-                issubclass(self.tag_field.field.remote_field.model, tag_models.TagModel)
-            )
+        self.assertTrue(
+            issubclass(self.tag_field.field.remote_field.model, tag_models.TagModel)
+        )
         self.assertTrue(issubclass(self.tag_field.tag_model, tag_models.TagModel))
 
     def test_empty_value(self):
@@ -163,7 +146,7 @@ class ModelTagFieldTest(TagTestManager, TestCase):
 
         # Returned before save
         self.assertEqual(t1.tags.get_tag_string(), "blue, red")
-        self.assertEqual(six.text_type(t1.tags), t1.tags.get_tag_string())
+        self.assertEqual(str(t1.tags), t1.tags.get_tag_string())
         self.assertEqual(len(t1.tags.get_tag_list()), 2)
         self.assertTrue("red" in t1.tags.get_tag_list())
         self.assertTrue("blue" in t1.tags.get_tag_list())
@@ -171,13 +154,13 @@ class ModelTagFieldTest(TagTestManager, TestCase):
 
         # Check db hasn't changed
         t2 = self.test_model.objects.get(name="Test 1")
-        self.assertEqual(six.text_type(t2.tags), "")
+        self.assertEqual(str(t2.tags), "")
 
         # Returned after save
         t1.save()
         t1 = self.test_model.objects.get(name="Test 1")
         self.assertEqual(t1.tags.get_tag_string(), "blue, red")
-        self.assertEqual(six.text_type(t1.tags), t1.tags.get_tag_string())
+        self.assertEqual(str(t1.tags), t1.tags.get_tag_string())
         self.assertEqual(len(t1.tags.get_tag_list()), 2)
         self.assertTrue("red" in t1.tags.get_tag_list())
         self.assertTrue("blue" in t1.tags.get_tag_list())
@@ -194,12 +177,12 @@ class ModelTagFieldTest(TagTestManager, TestCase):
         t1.tags = "red, blue"
 
         # Returned before save
-        self.assertEqual(six.text_type(t1.tags), "blue, red")
+        self.assertEqual(str(t1.tags), "blue, red")
         self.assertTagModel(self.tag_model, {})
 
         # Check db hasn't changed
         t2 = self.test_model.objects.get(name="Test 1")
-        self.assertEqual(six.text_type(t2.tags), "")
+        self.assertEqual(str(t2.tags), "")
 
         # Returned after save
         t1.tags.save()
@@ -212,12 +195,12 @@ class ModelTagFieldTest(TagTestManager, TestCase):
         t1.tags = ["red", "blue"]
 
         # Returned before save
-        self.assertEqual(six.text_type(t1.tags), "blue, red")
+        self.assertEqual(str(t1.tags), "blue, red")
         self.assertTagModel(self.tag_model, {})
 
         # Check db hasn't changed
         t2 = self.test_model.objects.get(name="Test 1")
-        self.assertEqual(six.text_type(t2.tags), "")
+        self.assertEqual(str(t2.tags), "")
 
         # Returned after save
         t1.tags.save()
@@ -233,12 +216,12 @@ class ModelTagFieldTest(TagTestManager, TestCase):
         ]
 
         # Returned before save
-        self.assertEqual(six.text_type(t1.tags), "blue, red")
+        self.assertEqual(str(t1.tags), "blue, red")
         self.assertTagModel(self.tag_model, {"red": 0, "blue": 0})
 
         # Check db hasn't changed
         t2 = self.test_model.objects.get(name="Test 1")
-        self.assertEqual(six.text_type(t2.tags), "")
+        self.assertEqual(str(t2.tags), "")
 
         # Returned after save
         t1.tags.save()
@@ -253,7 +236,7 @@ class ModelTagFieldTest(TagTestManager, TestCase):
         t1.tags = self.tag_model.objects.all()
 
         # Returned before save, check DB hasn't changed
-        self.assertEqual(six.text_type(t1.tags), "blue, red")
+        self.assertEqual(str(t1.tags), "blue, red")
         self.assertInstanceEqual(t1, name="Test 1", tags="")
         self.assertTagModel(self.tag_model, {"red": 0, "blue": 0})
 
@@ -269,7 +252,7 @@ class ModelTagFieldTest(TagTestManager, TestCase):
         t1.tags = ""
 
         # Returned before save, check DB hasn't changed
-        self.assertEqual(six.text_type(t1.tags), "")
+        self.assertEqual(str(t1.tags), "")
         self.assertInstanceEqual(t1, name="Test 1", tags="blue, red")
         self.assertTagModel(self.tag_model, {"red": 1, "blue": 1})
 
@@ -286,12 +269,12 @@ class ModelTagFieldTest(TagTestManager, TestCase):
         t1.tags = []
 
         # Returned before save
-        self.assertEqual(six.text_type(t1.tags), "")
+        self.assertEqual(str(t1.tags), "")
         self.assertTagModel(self.tag_model, {"red": 1, "blue": 1})
 
         # Check db hasn't changed
         t2 = self.test_model.objects.get(name="Test 1")
-        self.assertEqual(six.text_type(t2.tags), "blue, red")
+        self.assertEqual(str(t2.tags), "blue, red")
 
         # Returned after save
         t1.tags.save()
@@ -306,12 +289,12 @@ class ModelTagFieldTest(TagTestManager, TestCase):
         t1.tags = None
 
         # Returned before save
-        self.assertEqual(six.text_type(t1.tags), "")
+        self.assertEqual(str(t1.tags), "")
         self.assertTagModel(self.tag_model, {"red": 1, "blue": 1})
 
         # Check db hasn't changed
         t2 = self.test_model.objects.get(name="Test 1")
-        self.assertEqual(six.text_type(t2.tags), "blue, red")
+        self.assertEqual(str(t2.tags), "blue, red")
 
         # Returned after save
         t1.tags.save()
@@ -324,9 +307,7 @@ class ModelTagFieldTest(TagTestManager, TestCase):
         with self.assertRaises(ValueError) as cm:
             # Assign the descriptor to itself, because why not.
             t1.tags = self.test_model.tags
-        self.assertEqual(
-            six.text_type(cm.exception), "Unexpected value assigned to TagField"
-        )
+        self.assertEqual(str(cm.exception), "Unexpected value assigned to TagField")
 
     def test_contains(self):
         "Check __contains__ using strings and Tag objects"
@@ -524,7 +505,7 @@ class ModelTagFieldTest(TagTestManager, TestCase):
 
         # Returned before save
         t1.tags.clear()
-        self.assertEqual(six.text_type(t1.tags), "")
+        self.assertEqual(str(t1.tags), "")
         self.assertTagModel(self.tag_model, {"red": 1, "blue": 1})
         self.assertInstanceEqual(t1, name="Test 1", tags="")
         self.assertInstanceEqual(t2, name="Test 2", tags="blue, red")
@@ -551,40 +532,32 @@ class ModelTagFieldTest(TagTestManager, TestCase):
 
     def test_fake_manager(self):
         "Check that the FakeTagRelatedManager doesn't do databases"
-        if django.VERSION < (2, 0):
-            errmsg = (
-                '"<{model_name}: {model_name} object>" needs to be '
-                "saved before TagField can use the database"
-            )
-        else:
-            # Django 2.0 adds primary key to model __str__ and __repr__
-            errmsg = (
-                '"<{model_name}: {model_name} object (None)>" needs to be '
-                "saved before TagField can use the database"
-            )
-        errmsg = errmsg.format(model_name=self.test_model._meta.object_name)
+        errmsg = (
+            '"<{model_name}: {model_name} object (None)>" needs to be '
+            "saved before TagField can use the database"
+        ).format(model_name=self.test_model._meta.object_name)
 
         t1 = self.test_model(name="Test 1", tags="blue, red")
 
         with self.assertRaises(ValueError) as cm:
             t1.tags.save()
-        self.assertEqual(six.text_type(cm.exception), errmsg)
+        self.assertEqual(str(cm.exception), errmsg)
 
         with self.assertRaises(ValueError) as cm:
             t1.tags.set("fail")
-        self.assertEqual(six.text_type(cm.exception), errmsg)
+        self.assertEqual(str(cm.exception), errmsg)
 
         with self.assertRaises(ValueError) as cm:
             t1.tags.add("fail")
-        self.assertEqual(six.text_type(cm.exception), errmsg)
+        self.assertEqual(str(cm.exception), errmsg)
 
         with self.assertRaises(ValueError) as cm:
             t1.tags.remove("blue")
-        self.assertEqual(six.text_type(cm.exception), errmsg)
+        self.assertEqual(str(cm.exception), errmsg)
 
         with self.assertRaises(ValueError) as cm:
             t1.tags.clear()
-        self.assertEqual(six.text_type(cm.exception), errmsg)
+        self.assertEqual(str(cm.exception), errmsg)
 
     def test_prefetch_related(self):
         self.create(self.test_model, name="Test 1", tags="blue, green")
@@ -661,7 +634,7 @@ class ModelTagFieldInvalidTest(TagTestManager, TransactionTestCase):
         with self.assertRaises(ValueError) as cm:
             new_field._process_deferred_options()
         self.assertEqual(
-            six.text_type(cm.exception),
+            str(cm.exception),
             "Cannot set tag options on explicit tag model "
             "<class 'tests.tagulous_tests_app.models.TagMetaUser'>",
         )
@@ -686,9 +659,7 @@ class ModelTagFieldInvalidTest(TagTestManager, TransactionTestCase):
             class FailModel_invalid_to(models.Model):
                 to_model = tag_models.TagField(test_models.TagFieldModel)
 
-        self.assertEqual(
-            six.text_type(cm.exception), "Tag model must be a subclass of TagModel"
-        )
+        self.assertEqual(str(cm.exception), "Tag model must be a subclass of TagModel")
 
     def test_forbidden_db_table(self):
         "Check that db_table argument raises exception"
@@ -697,9 +668,7 @@ class ModelTagFieldInvalidTest(TagTestManager, TransactionTestCase):
             class FailModel_forbidden_db(models.Model):
                 db_table = tag_models.TagField(db_table="fail")
 
-        self.assertEqual(
-            six.text_type(cm.exception), "Invalid argument 'db_table' for TagField"
-        )
+        self.assertEqual(str(cm.exception), "Invalid argument 'db_table' for TagField")
 
     def test_forbidden_through(self):
         "Check that through argument raises exception"
@@ -708,9 +677,7 @@ class ModelTagFieldInvalidTest(TagTestManager, TransactionTestCase):
             class FailModel_forbidden_through(models.Model):
                 through = tag_models.TagField(through="fail")
 
-        self.assertEqual(
-            six.text_type(cm.exception), "Invalid argument 'through' for TagField"
-        )
+        self.assertEqual(str(cm.exception), "Invalid argument 'through' for TagField")
 
     def test_forbidden_symmetrical(self):
         "Check that symmetrical argument raises exception"
@@ -720,10 +687,9 @@ class ModelTagFieldInvalidTest(TagTestManager, TransactionTestCase):
                 symmetrical = tag_models.TagField(symmetrical="fail")
 
         self.assertEqual(
-            six.text_type(cm.exception), "Invalid argument 'symmetrical' for TagField"
+            str(cm.exception), "Invalid argument 'symmetrical' for TagField"
         )
 
-    @unittest.skipIf(ChecksWarning is None, "Check test only run for Django 1.9+")
     def test_nulled_tag_field(self):
         "Check model field raises warning when given invalid null"
         nulled_tagfield = tag_models.TagField(null=True)
@@ -1004,10 +970,7 @@ class ModelTagFieldStringTest(TagTestManager, TransactionTestCase):
     def test_to_model(self):
         "Check related model is correct"
         self.assertTrue(issubclass(self.tag_field.tag_model, tag_models.TagModel))
-        if django.VERSION < (1, 9):
-            self.assertEqual(self.tag_field.field.remote_field.to, self.tag_model)
-        else:
-            self.assertEqual(self.tag_field.field.remote_field.model, self.tag_model)
+        self.assertEqual(self.tag_field.field.remote_field.model, self.tag_model)
         self.assertEqual(self.tag_field.tag_model, self.tag_model)
 
     def test_tag_options(self):
@@ -1036,10 +999,7 @@ class ModelTagFieldSelfTest(TagTestManager, TransactionTestCase):
     def test_to_model(self):
         "Check related model is correct"
         self.assertTrue(issubclass(self.tag_field.tag_model, tag_models.TagModel))
-        if django.VERSION < (1, 9):
-            self.assertEqual(self.tag_field.field.remote_field.to, self.test_model)
-        else:
-            self.assertEqual(self.tag_field.field.remote_field.model, self.test_model)
+        self.assertEqual(self.tag_field.field.remote_field.model, self.test_model)
         self.assertEqual(self.tag_field.tag_model, self.test_model)
 
     def test_tag_options(self):
@@ -1225,9 +1185,7 @@ class ModelTagFieldOptionsTest(TagTestManager, TransactionTestCase):
             self.test_model.objects.create(
                 name="Test 1", max_count="Adam, Brian, Chris, David"
             )
-        self.assertEqual(
-            six.text_type(cm.exception), "Cannot set more than 3 tags on this field"
-        )
+        self.assertEqual(str(cm.exception), "Cannot set more than 3 tags on this field")
         with self.assertRaises(self.test_model.DoesNotExist) as cm:
             self.test_model.objects.get(name="Test 1")
         self.assertTagModel(self.test_model.max_count, {})
@@ -1245,9 +1203,7 @@ class ModelTagFieldOptionsTest(TagTestManager, TransactionTestCase):
         t1 = self.create(self.test_model, name="Test 1")
         with self.assertRaises(ValueError) as cm:
             t1.max_count = "Adam, Brian, Chris, David"
-        self.assertEqual(
-            six.text_type(cm.exception), "Cannot set more than 3 tags on this field"
-        )
+        self.assertEqual(str(cm.exception), "Cannot set more than 3 tags on this field")
         self.assertInstanceEqual(t1, name="Test 1", max_count="")
         self.assertTagModel(self.test_model.max_count, {})
 
@@ -1256,7 +1212,7 @@ class ModelTagFieldOptionsTest(TagTestManager, TransactionTestCase):
         with self.assertRaises(ValueError) as cm:
             t1.max_count.add("Chris", "David")
         self.assertEqual(
-            six.text_type(cm.exception),
+            str(cm.exception),
             "Cannot set more than 3 tags on this field; it already has 2",
         )
         self.assertInstanceEqual(t1, name="Test 1", max_count="Adam, Brian")
